︠74a31f61-19b2-47ad-a4be-16708c3268f5i︠
%html
<h2>SIR epidemic model (Kermack-McKendrick)</h2>

<p>In this model, there are three classes of individuals: Susceptible, Infected, and Recovered (or Removed).
Susceptible individuals are infected at a rate of &beta; times the number of infected individuals, I.
Infected individuals recover at a rate of &nu;.
Vital dynamics have been added using the parameter &mu;, which is the rate at which new susceptibles
are introduced and susceptibles, infecteds, and recovereds are depleted (birth and death rate).</p>

<p>This demo plots the number of infected (red) and susceptible (blue) individuals over time,
as well as a phase plot (fraction of susceptibles vs fraction of infecteds) in green.
You can set &beta;, &nu;, and the initial number of susceptible and infected individuals.</p>

︡cc7293c7-f565-47d6-a3ac-2444979a832d︡{"html": "<h2>SIR epidemic model (Kermack-McKendrick)</h2>\r\n\r\n<p>In this model, there are three classes of individuals: Susceptible, Infected, and Recovered (or Removed).\r\nSusceptible individuals are infected at a rate of &beta; times the number of infected individuals, I.\r\nInfected individuals recover at a rate of &nu;.\r\nVital dynamics have been added using the parameter &mu;, which is the rate at which new susceptibles\r\nare introduced and susceptibles, infecteds, and recovereds are depleted (birth and death rate).</p>\r\n\r\n<p>This demo plots the number of infected (red) and susceptible (blue) individuals over time,\r\nas well as a phase plot (fraction of susceptibles vs fraction of infecteds) in green.\r\nYou can set &beta;, &nu;, and the initial number of susceptible and infected individuals.</p>"}︡
︠cf8ac34d-741a-4753-a9e2-482e92600d4es︠
# SIR epidemic model (Kermack-McKendrick model)
import numpy
import scipy
from scipy.integrate import odeint
from sage.plot.line import Line

@interact
def euler_method(beta = input_box(2, label = 'β: '), nu = input_box(0.8, label = 'ν: '), mu = input_box(0, label = 'μ: '), tmax = input_box(20, label = 'max t: '), Ifrac = slider(0,1,0.05,label='Initial fraction infected: ', default=0.05)):
  html(r"$\displaystyle\frac{dS}{dt} = \mu - \mu S - \beta S I$")
  html(r"$\displaystyle\frac{dI}{dt} = \beta S I - \mu I - \nu I$")
  
  def dXdt(X,t):
    dX1dt = (mu - mu*X[0] - beta*X[0]*X[1])
    dX2dt = (beta*X[0]*X[1] - mu*X[1] - nu*X[1])
    return numpy.array([dX1dt, dX2dt], dtype=float)
    
  t = numpy.arange(0,tmax,0.1)
  pts = odeint(dXdt,[1.0-Ifrac, Ifrac],t)
  pts_S = [[t[i],pts[i][0]] for i in range(len(t))]
  pts_I = [[t[i],pts[i][1]] for i in range(len(t))]
  show(line(pts_S, rgbcolor=(0,0,1)) + line(pts_I, rgbcolor=(1,0,0)) + text("S", (0.1,1-Ifrac), rgbcolor=(0,0,1)) + text("I", (0.1,Ifrac), rgbcolor=(1,0,0)), axes_labels=['time', ''], ymax=1)

  html("<h2>Phase plane</h2>")
  P1 = line([(0,1),(1,0)], rgbcolor=(0,0,0))
  t = numpy.arange(0,10,0.1)
  for i in range(1,10):
      I0 = i/10.0
      S0 = 1.0-I0
      pts = odeint(dXdt,[S0, I0], t) 
      pts_xy = [[x[0],x[1]] for x in pts]
      P1 = P1+line(pts_xy, rgbcolor=(0,1,0))
      
  show(P1,xmin=0,ymin=0,xmax=1,ymax=1, axes_labels=['Susceptible fraction', 'Infected fraction'])
︡4c4eb549-2b12-4e23-b764-987dab4ce882︡{"interact":{"style":"None","flicker":false,"layout":[[["beta",12,null]],[["nu",12,null]],[["mu",12,null]],[["tmax",12,null]],[["Ifrac",12,null]],[["",12,null]]],"id":"512c8e6c-264e-48bf-95fe-ae8c9c5f24e5","controls":[{"control_type":"input-box","default":2,"label":"β: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"beta","type":null},{"control_type":"input-box","default":"0.800000000000000","label":"ν: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"nu","type":null},{"control_type":"input-box","default":0,"label":"μ: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"mu","type":null},{"control_type":"input-box","default":20,"label":"max t: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"tmax","type":null},{"control_type":"slider","default":1,"var":"Ifrac","width":null,"vals":["0.000000000000000","0.0500000000000000","0.100000000000000","0.150000000000000","0.200000000000000","0.250000000000000","0.300000000000000","0.350000000000000","0.400000000000000","0.450000000000000","0.500000000000000","0.550000000000000","0.600000000000000","0.650000000000000","0.700000000000000","0.750000000000000","0.800000000000000","0.850000000000000","0.900000000000000","0.950000000000000","1.00000000000000"],"animate":true,"label":"Initial fraction infected: ","display_value":true}]}}︡
︠b2e997f2-598c-427f-9b1f-40edae4e66b9︠









